apis/affogato_apis library

Classes

AffogatoAPI
An abstraction over the AffogatoEvents class and over commonly-accessed objects such as AffogatoWorkspaceConfigs. Each API in AffogatoAPI has to be instantiated by the user, since each API has its own configurations.
AffogatoAPIComponent
AffogatoDocument
Stores information about the source, including the path to the file and its contents.
AffogatoEditorAPI
AffogatoEditorKeybindingExtension
This class is for extensions that override the default behaviour of keys when typing into the editor. It is not to be confused with:
AffogatoExtension
AffogatoExtensionsAPI
AffogatoExtensionsEngine
AffogatoPanesAPI
AffogatoVFSAPI
AffogatoWindowAPI
AffogatoWorkspaceAPI
AST
ASTNode
Cursor
CursorLocation
EditorTheme<C, Y>
ErroneousASTNode
InsignificantASTNode
Interpreter
LanguageBundle
NonTerminalASTNode
ParseException
Parser
ParseResult
SyntaxHighlighter<T>
The SyntaxHighlighter generates a sequence of highlight tokens. Each token is a record of type (String, T), where the first item is the text itself, and T is the type of the highlighting format.
SyntaxTokenRenderer<T, D>
A SyntaxTokenRenderer's job is to take a sequence of highlighted tokens, each of type T, and produce an output object of type D that can be directly shown by the editor.
TerminalASTNode
ThemeBundle<S, C, Y, D>
This is what the type generics mean:
Token
TokenCursor
Tokeniser
TokenMapping<K, V>
Generates a Map whose keys are of type K and values type V. This provides a better way to natively define token mappings, by allowing token scopes to be grouped, named, and for text styles to be overriden.
TokenType
VSCodeEditorTheme<C, Y>

Extensions

StringUtils on String

Constants

eofStr → const String

Typedefs

Char = String