AST class

Constructors

AST({required List<ASTNode> nodes})

Properties

hashCode int
The hash code for this object.
no setterinherited
nodes List<ASTNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalNodes List<TerminalASTNode>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reconstructSource() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited