AffogatoExtensionsAPI class final

Inheritance

Constructors

AffogatoExtensionsAPI({required AffogatoExtensionsEngine extensionsEngine})

Properties

api AffogatoAPI
latefinalinherited
engine AffogatoExtensionsEngine
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deinit() → void
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(AffogatoExtension extension) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited