AffogatoPanesAPI class

Inheritance
Mixed-in types

Constructors

AffogatoPanesAPI()

Properties

api AffogatoAPI
latefinalinherited
cellLayoutChangedStream Stream<WindowPaneCellLayoutChangedEvent>
final
cellRequestReloadStream Stream<WindowPaneCellRequestReloadEvent>
final
hashCode int
The hash code for this object.
no setterinherited
requestReloadStream Stream<WindowPaneRequestReloadEvent>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDefaultPane(String paneId) → void
This method is called when it is known for sure that removing a given pane will result in no more panes being left (which is an erroneous state) and therefore a default, empty pane given by paneId is requested to be added.
addPane({required Axis axis, required String anchorCellId, required String anchorPaneId, required String newPaneId, required bool insertPrev}) → void
addPaneBottom({required String anchorCellId, required String anchorPaneId, required String newPaneId}) → void
addPaneLeft({required String anchorCellId, required String anchorPaneId, required String newPaneId}) → void
addPaneRight({required String anchorCellId, required String anchorPaneId, required String newPaneId}) → void
addPaneTop({required String anchorCellId, required String anchorPaneId, required String newPaneId}) → void
cancelSubscriptions() Future<void>
inherited
findCellById(String cellId) PaneList
Traverse via BFS
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerListener<E>(Stream<E> stream, void callback(E event)) → void
Wraps the stream.listen with two additional benefits:
inherited
removePane() → void
splitIntoTwoPanes({required String paneIdA, required String paneIdB, required double width, required double height, required Axis axis, String? cellIdA, String? cellIdB}) List<PaneList>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited