Cursor class

Constructors

Cursor(String source)

Properties

charMap List<List<Char>>
final
col int
getter/setter pair
current Char
no setter
hashCode int
The hash code for this object.
no setterinherited
reachedEOF bool
no setter
row int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final

Methods

advance() Char
location() CursorLocation
nextMatches(Char target) bool
nextMatchesAny(List<Char> targets) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek({int lookAhead = 1, int? r, int? c}) List<Char>
skip() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited