CursorLocation class

Constructors

CursorLocation({required int rowNum, required int colNum})
const

Properties

colNum int
final
hashCode int
The hash code for this object.
no setterinherited
rowNum int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(CursorLocation? other) CursorLocation
operator -(CursorLocation other) CursorLocation
operator <(CursorLocation other) bool
operator <=(CursorLocation other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(CursorLocation other) bool
operator >=(CursorLocation other) bool