InsignificantASTNode class

Inheritance

Constructors

InsignificantASTNode()

Properties

end CursorLocation
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lexeme String
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
finalinherited
start CursorLocation
no setterinherited
tokens List<Token>
finalinherited

Methods

lexemeRepresentation() String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPrettyString([int indent = 1]) String
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited