LanguageBundle class
Constructors
-
LanguageBundle({required String bundleName, required List<
String> fileAssociationContributions, Tokeniser? tokeniser, Parser? parser, Interpreter? interpreter}) -
const
Properties
- bundleName → String
-
final
-
fileAssociationContributions
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpreter → Interpreter?
-
final
- parser → Parser?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokeniser → Tokeniser?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited