SyntaxHighlighter<T> class abstract

The SyntaxHighlighter generates a sequence of highlight tokens. Each token is a record of type (String, T), where the first item is the text itself, and T is the type of the highlighting format.

Implementers

Constructors

SyntaxHighlighter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRenderTokens(String text) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited