SyntaxTokenRenderer<T, D> class abstract

A SyntaxTokenRenderer's job is to take a sequence of highlighted tokens, each of type T, and produce an output object of type D that can be directly shown by the editor.

Implementers

Constructors

SyntaxTokenRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(T tokens) → D
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited