TerminalASTNode class abstract

Inheritance
Implementers

Constructors

TerminalASTNode(String name, {required List<String> scopes})

Properties

end CursorLocation
no setter
hashCode int
The hash code for this object.
no setterinherited
lexeme String
no setter
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
start CursorLocation
no setter
tokens List<Token>
final

Methods

lexemeRepresentation() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPrettyString([int indent = 1]) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited