ThemeBundle<S, C, Y, D> class

This is what the type generics mean:

  • S is the type of the syntax highlighting tokens generated by the SyntaxHighlighter
  • C represents the colour class being used. On Flutter, this should be Color
  • Y represents the text styling class being used. On Flutter, this should be TextStyle
  • D represents the output of the SyntaxTokenRenderer. Affogato Editor uses an underlying TextField, and therefore, requires D to be a TextSpan.
  • The EditorTheme should therefore represent colours with C and text styles with Y

Constructors

ThemeBundle({required EditorTheme<C, Y> editorTheme, required Map<String, Y> tokenMapping})
const

Properties

editorTheme EditorTheme<C, Y>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenMapping Map<String, Y>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited