Token class

Constructors

Token({required TokenType tokenType, required String lexeme, required CursorLocation start, required CursorLocation end, Object? literal})
const

Properties

end CursorLocation
final
hashCode int
The hash code for this object.
no setterinherited
lexeme String
final
literal Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start CursorLocation
final
tokenType TokenType
final

Methods

containsChar(CursorLocation location) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPrettyString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override