tokens property
The last Token must be an EOF token for the TokenCursor to work. Always add a Token with the TokenType.eof type at the end of the tokenisation process.
Implementation
final List<Token> tokens;
The last Token must be an EOF token for the TokenCursor to work. Always add a Token with the TokenType.eof type at the end of the tokenisation process.
final List<Token> tokens;