VSCodeEditorTheme<C, Y> class
- Inheritance
-
- Object
- EditorTheme<
C, Y> - VSCodeEditorTheme
Constructors
- VSCodeEditorTheme({required C? parseColor(String?), required String? colorToString(C?), required Y defaultTextStyle})
-
VSCodeEditorTheme.fromJson(Map<
String, dynamic> json, {required C? parseColor(String?), required String? colorToString(C?), required Y defaultTextStyle})
Properties
- actionBarToggledBackground → C?
-
finalinherited
- activityBarActiveBorder → C?
-
finalinherited
- activityBarBackground → C?
-
finalinherited
- activityBarBadgeBackground → C?
-
finalinherited
- activityBarBadgeForeground → C?
-
finalinherited
- activityBarBorder → C?
-
finalinherited
- activityBarForeground → C?
-
finalinherited
- activityBarInactiveForeground → C?
-
finalinherited
- badgeBackground → C?
-
finalinherited
- badgeForeground → C?
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
- chatEditedFileForeground → C?
-
finalinherited
- chatSlashCommandBackground → C?
-
finalinherited
- chatSlashCommandForeground → C?
-
finalinherited
- checkboxBackground → C?
-
finalinherited
- checkboxBorder → C?
-
finalinherited
- colorToString → String? Function(C?)
-
final
- debugToolBarBackground → C?
-
finalinherited
- defaultTextStyle → Y
-
finalinherited
- descriptionForeground → C?
-
finalinherited
- dropdownBackground → C?
-
finalinherited
- dropdownBorder → C?
-
finalinherited
- dropdownForeground → C?
-
finalinherited
- dropdownListBackground → C?
-
finalinherited
- editorBackground → C?
-
finalinherited
- editorFindMatchBackground → C?
-
finalinherited
- editorForeground → C?
-
finalinherited
- editorGroupBorder → C?
-
finalinherited
- editorGroupHeaderTabsBackground → C?
-
finalinherited
- editorGroupHeaderTabsBorder → C?
-
finalinherited
- editorGutterAddedBackground → C?
-
finalinherited
- editorGutterDeletedBackground → C?
-
finalinherited
- editorGutterModifiedBackground → C?
-
finalinherited
- editorInactiveSelectionBackgroundAndTerminalInactiveSelectionBackground → C?
-
finalinherited
- editorIndentGuideActiveBackground1 → C?
-
finalinherited
- editorIndentGuideBackground1 → C?
-
finalinherited
- editorLineNumberActiveForeground → C?
-
finalinherited
- editorLineNumberForeground → C?
-
finalinherited
- editorOverviewRulerBorder → C?
-
finalinherited
- editorSelectionHighlightBackground → C?
-
finalinherited
- editorWidgetBackground → C?
-
finalinherited
- errorForeground → C?
-
finalinherited
- focusBorder → C?
-
finalinherited
- foreground → C?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconForeground → C?
-
finalinherited
- inputBackground → C?
-
finalinherited
- inputBorder → C?
-
finalinherited
- inputForeground → C?
-
finalinherited
- inputOptionActiveBackground → C?
-
finalinherited
- inputOptionActiveBorder → C?
-
finalinherited
- inputPlaceholderForeground → C?
-
finalinherited
- keybindingLabelForeground → C?
-
finalinherited
- listActiveSelectionIconForeground → C?
-
finalinherited
- listDropBackground → C?
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
-
finalinherited
- notificationCenterHeaderBackground → C?
-
finalinherited
- notificationCenterHeaderForeground → C?
-
finalinherited
- notificationsBackground → C?
-
finalinherited
- notificationsBorder → C?
-
finalinherited
- notificationsForeground → C?
-
finalinherited
- panelBackground → C?
-
finalinherited
- panelBorder → C?
-
finalinherited
- panelInputBorder → C?
-
finalinherited
- panelTitleActiveBorder → C?
-
finalinherited
- panelTitleActiveForeground → C?
-
finalinherited
- panelTitleInactiveForeground → C?
-
finalinherited
- parseColor → C? Function(String?)
-
final
- peekViewEditorBackground → C?
-
finalinherited
- peekViewEditorMatchHighlightBackground → C?
-
finalinherited
- peekViewResultBackground → C?
-
finalinherited
- peekViewResultMatchHighlightBackground → C?
-
finalinherited
- pickerGroupBorder → C?
-
finalinherited
- portsIconRunningProcessForeground → C?
-
finalinherited
- progressBarBackground → C?
-
finalinherited
- quickInputBackground → C?
-
finalinherited
- quickInputForeground → C?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingsDropdownBackground → C?
-
finalinherited
- settingsDropdownBorder → C?
-
finalinherited
- settingsHeaderForeground → C?
-
finalinherited
- settingsModifiedItemIndicator → C?
-
finalinherited
- sideBarBackground → C?
-
finalinherited
- sideBarBorder → C?
-
finalinherited
- sideBarForeground → C?
-
finalinherited
- sideBarSectionHeaderBackground → C?
-
finalinherited
- sideBarSectionHeaderBorder → C?
-
finalinherited
- sideBarSectionHeaderForeground → C?
-
finalinherited
- sideBarTitleForeground → C?
-
finalinherited
- statusBarBackground → C?
-
finalinherited
- statusBarBorder → C?
-
finalinherited
- statusBarDebuggingBackground → C?
-
finalinherited
- statusBarDebuggingForeground → C?
-
finalinherited
- statusBarFocusBorder → C?
-
finalinherited
- statusBarForeground → C?
-
finalinherited
- statusBarItemFocusBorder → C?
-
finalinherited
- statusBarItemProminentBackground → C?
-
finalinherited
- statusBarItemRemoteBackground → C?
-
finalinherited
- statusBarItemRemoteForeground → C?
-
finalinherited
- statusBarNoFolderBackground → C?
-
finalinherited
- tabActiveBackground → C?
-
finalinherited
- tabActiveBorder → C?
-
finalinherited
- tabActiveBorderTop → C?
-
finalinherited
- tabActiveForeground → C?
-
finalinherited
- tabBorder → C?
-
finalinherited
- tabHoverBackground → C?
-
finalinherited
- tabInactiveBackground → C?
-
finalinherited
- tabInactiveForeground → C?
-
finalinherited
- tabLastPinnedBorder → C?
-
finalinherited
- tabSelectedBackground → C?
-
finalinherited
- tabSelectedBorderTop → C?
-
finalinherited
- tabSelectedForeground → C?
-
finalinherited
- tabUnfocusedActiveBorder → C?
-
finalinherited
- tabUnfocusedActiveBorderTop → C?
-
finalinherited
- tabUnfocusedHoverBackground → C?
-
finalinherited
- terminalForeground → C?
-
finalinherited
- terminalTabActiveBorder → C?
-
finalinherited
- textBlockQuoteBackground → C?
-
finalinherited
- textBlockQuoteBorder → C?
-
finalinherited
- textCodeBlockBackground → C?
-
finalinherited
- textLinkActiveForeground → C?
-
finalinherited
- textLinkForeground → C?
-
finalinherited
- textPreformatBackground → C?
-
finalinherited
- textPreformatForeground → C?
-
finalinherited
- textSeparatorForeground → C?
-
finalinherited
- titleBarActiveBackground → C?
-
finalinherited
- titleBarActiveForeground → C?
-
finalinherited
- titleBarBorder → C?
-
finalinherited
- titleBarInactiveBackground → C?
-
finalinherited
- titleBarInactiveForeground → C?
-
finalinherited
- welcomePageProgressForeground → C?
-
finalinherited
- welcomePageTileBackground → C?
-
finalinherited
- widgetBorder → C?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited