AffogatoConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- completionsMenuItemHeight → const double
- completionsMenuWidth → const double
- lineHeight → const double
- lineNumbersColWidth → const double
- lineNumbersGutterRightmostPadding → const double
- lineNumbersGutterWidth → const double
- overscrollAmount → const double
- primaryBarClosedWidth → const double
- primaryBarExpandedWidth → const double
- primaryBarFileTreeIndentSize → const double
- primaryBarFileTreeItemDirIconSize → const double
- primaryBarFileTreeItemFileIconSize → const double
- primaryBarFileTreeItemHeight → const double
- primaryBarFileTreeItemIconTextPadding → const double
- searchAndReplacePadding → const double
- searchAndReplaceRowItemHeight → const double
- searchAndReplaceTextFieldWidth → const double
- searchAndReplaceWidgetWidth → const double
- statusBarHeight → const double
- tabBarPadding → const double