StreamSubscriptionManager<T extends StatefulWidget> mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelSubscriptions() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerListener<E>(Stream<E> stream, void callback(E event)) → void
Wraps the stream.listen with two additional benefits:
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited