AffogatoDefaultRenderer class

Inheritance

Constructors

AffogatoDefaultRenderer({required TextStyle defaultStyle, required Map<String, TextStyle> mapping})

Properties

defaultStyle TextStyle
final
hashCode int
The hash code for this object.
no setterinherited
mapping Map<String, TextStyle>
final
renderer → TextSpanRenderer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(HighlightResult tokens) TextSpan?
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited