AffogatoDefaultSyntaxHighlighter class

The default syntax highligher uses the HighlightJS equivalent in Dart, made possible by the re_highlight package.

Inheritance

Constructors

AffogatoDefaultSyntaxHighlighter(String? language)

Properties

hashCode int
The hash code for this object.
no setterinherited
highlight → Highlight
final
language String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRenderTokens(String text) → HighlightResult
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited