AffogatoEditorFieldController<S, SyntaxHighlighter> class

Inheritance

Constructors

AffogatoEditorFieldController({required LanguageBundle? languageBundle, required ThemeBundle<S, Color, TextStyle, TextSpan> themeBundle, required AffogatoWorkspaceConfigs workspaceConfigs, String? initialText})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
initialText → String?
final
languageBundle → LanguageBundle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ TextSelection
The currently selected range within text.
getter/setter pairinherited
syntaxHighlighter → AffogatoDefaultSyntaxHighlighter
final
text ↔ String
The current string the user is editing.
getter/setter pairinherited-getteroverride-setter
themeBundle → ThemeBundle<S, Color, TextStyle, TextSpan>
final
value ↔ TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited
workspaceConfigs → AffogatoWorkspaceConfigs
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, TextStyle? style, required bool withComposing}) → TextSpan
Builds TextSpan from current editing value.
override
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited