AffogatoEditorInstanceData class
- Inheritance
-
- Object
- PaneInstanceData
- AffogatoEditorInstanceData
Constructors
-
AffogatoEditorInstanceData({required String documentId, required LanguageBundle? languageBundle, required ThemeBundle<
dynamic, Color, TextStyle, TextSpan> themeBundle})
Properties
- documentId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageBundle → LanguageBundle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
themeBundle
→ ThemeBundle<
dynamic, Color, TextStyle, TextSpan> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited