AffogatoEditorInstanceState class
- Inheritance
-
- Object
- State<
PaneInstance< AffogatoEditorInstanceData> > - AffogatoEditorInstanceState
- Mixed-in types
Constructors
Properties
- cellHeight ↔ double
-
getter/setter pair
- cellWidth ↔ double
-
getter/setter pair
- codeTextStyle ↔ TextStyle
-
getter/setter pair
- completionsController ↔ CompletionsController
-
latefinal
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- currentCharNum ↔ int
-
getter/setter pair
- currentLineNum ↔ int
-
getter/setter pair
- data ↔ AffogatoEditorInstanceData
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasScrolled ↔ bool
-
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
final
- searchAndReplaceController → LocalSearchAndReplaceController
-
latefinal
- textController ↔ AffogatoEditorFieldController
-
getter/setter pair
- textFieldFocusNode → FocusNode
-
final
-
widget
→ PaneInstance<
AffogatoEditorInstanceData> -
The current configuration.
no setterinherited
Methods
-
acceptAndDismissCompletionsWidget(
String insertText) → void -
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
cancelSubscriptions(
) → Future< void> -
inherited
-
createTicker(
TickerCallback onTick) → Ticker -
Creates a ticker with the given callback.
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant PaneInstance< AffogatoEditorInstanceData> oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
generateIndentationRulers(
) → List< Row> -
generateLeftGutterWidgets(
) → List< Widget> - Generates the Git diff indicators and code folding buttons.
-
generateLineNumbers(
) → List< Widget> -
getData(
{AffogatoEditorInstanceData onNull()?, AffogatoEditorInstanceData onWrongDataType(PaneInstanceData?)?}) → void -
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
insertTextAtCursorPos(
String text, {bool moveCursorToEnd = true}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
registerListener<
E> (Stream< E> stream, void callback(E event)) → void -
Wraps the
stream.listenwith two additional benefits:inherited -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited