editorKeyEventsController property
Emitted for key presses while focus is currently on the TextField of a specific instance.
Implementation
static final StreamController<EditorKeyEvent> editorKeyEventsController =
StreamController.broadcast();
Emitted for key presses while focus is currently on the TextField of a specific instance.
static final StreamController<EditorKeyEvent> editorKeyEventsController =
StreamController.broadcast();