windowPaneCellLayoutChangedEventsController property

StreamController<WindowPaneCellLayoutChangedEvent> windowPaneCellLayoutChangedEventsController
final

Emitted whenever the layout of panes in the window changes. A listener in the Panes API then re-computes the new layout and requests affected pane cells to rebuild via the windowPaneCellRequestReloadEventsController.

Implementation

static final StreamController<WindowPaneCellLayoutChangedEvent>
    windowPaneCellLayoutChangedEventsController =
    StreamController.broadcast();