windowPaneCellRequestReloadEventsController property

StreamController<WindowPaneCellRequestReloadEvent> windowPaneCellRequestReloadEventsController
final

Emitted to request a specific pane cell to relayout its children based on new constraints (assuming the constraints have already been computed and stored in the workspace data). Each pane cell then emits an event with the cell ID of its immediate children. For reload requests due to changes in the data of a specific pane, see windowPaneRequestReloadEventsController.

Implementation

static final StreamController<WindowPaneCellRequestReloadEvent>
    windowPaneCellRequestReloadEventsController =
    StreamController.broadcast();