windowPaneRequestReloadEventsController property

StreamController<WindowPaneRequestReloadEvent> windowPaneRequestReloadEventsController
final

Emitted to request a specific pane to reload its state, due to changes in its data. For reloads pertaining to changes in layout, see windowPaneCellRequestReloadEventsController, which rebuilds of descendants as well.

Implementation

static final StreamController<WindowPaneRequestReloadEvent>
    windowPaneRequestReloadEventsController = StreamController.broadcast();