AffogatoStylingConfigs class

Constructors

AffogatoStylingConfigs({required double windowHeight, required double windowWidth, required double tabBarHeight, required double editorFontSize, int tabSizeInSpaces = 4})
const

Properties

editorFontSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabBarHeight double
final
tabSizeInSpaces int
final
windowHeight double
final
windowWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited