AffogatoVFSEntity class

Constructors

AffogatoVFSEntity.dir({required String entityId, required String name, required List<AffogatoVFSEntity> files, required List<AffogatoVFSEntity> subdirs})
AffogatoVFSEntity.file({required String entityId, required AffogatoDocument doc})

Properties

document AffogatoDocument?
File-only properties
getter/setter pair
entityId String
final
files List<AffogatoVFSEntity>
final
hashCode int
The hash code for this object.
no setteroverride
isDirectory bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subdirs List<AffogatoVFSEntity>
Directory-only properties
final

Methods

dumpTree(int indent) String
findById(String id, {bool? isDir, void stepCallback(AffogatoVFSEntity)?, void action(AffogatoVFSEntity?)?}) AffogatoVFSEntity?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override