languageBundles property
A mapping of LanguageBundles to possible file extensions for each language Each entry will be checked first to find a suitable user-defined LanguageBundle for a given file extension, before the LanguageBundle.fileAssociationContributions that is provided by the creator of the language bundle is traversed.
Implementation
final Map<LanguageBundle, List<String>> languageBundles;