EditorKeyEvent class

Inheritance

Constructors

EditorKeyEvent({required KeyEvent keyEvent, required String instanceId, required EditingContext editingContext})
const

Properties

editingContext → EditingContext
final
eventId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
instanceId → String
final
keyEvent → KeyEvent
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited