KeyboardShortcutsDispatcher class

This class is responsible for detecting the start/end of keyboard shortcuts and for firing callbacks for registered shortcuts.

Constructors

KeyboardShortcutsDispatcher({required Stream<WindowKeyboardEvent> stream})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence List<LogicalKeyboardKey>
final
shortcuts Map<String, VoidCallback>
final

Methods

handleKeystroke(WindowKeyboardEvent event) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideShortcut(List<LogicalKeyboardKey> sequence, VoidCallback callback) → void
signatureOf(List<LogicalKeyboardKey> sequence) String
Generates a signature for a keyboard shortcut's key sequence
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited