LocalSearchAndReplaceData class
This object stores the state/data for the SearchAndReplaceWidget in an intra-file context.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matches
↔ Iterable<
Match> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchAndReplaceMatchHighlights
→ List<
Positioned> -
final
- searchItemCurrentIndex ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited