SetiIconColor enum

Inheritance
Available extensions

Values

white → const SetiIconColor
const SetiIconColor(Color(0xFFd4d7d6))
blue → const SetiIconColor
const SetiIconColor(Color(0xFF519aba))
grey → const SetiIconColor
const SetiIconColor(Color(0xFF4d5a5e))
green → const SetiIconColor
const SetiIconColor(Color(0xFF8dc149))
orange → const SetiIconColor
const SetiIconColor(Color(0xFFe37933))
pink → const SetiIconColor
const SetiIconColor(Color(0xFFf55385))
purple → const SetiIconColor
const SetiIconColor(Color(0xFFa074c4))
red → const SetiIconColor
const SetiIconColor(Color(0xFFcc3e44))
yellow → const SetiIconColor
const SetiIconColor(Color(0xFFcbcb41))
greyLight → const SetiIconColor
const SetiIconColor(Color(0xFF6d8086))
ignore → const SetiIconColor
const SetiIconColor(Color(0xFF41535b))

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SetiIconColor>
A constant List of the values in this enum, in order of their declaration.