VFSDocumentChangedEvent class

Inheritance

Constructors

VFSDocumentChangedEvent({required String newContent, required String documentId, required TextSelection selection, required String originId})
const

Properties

documentId String
final
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
newContent String
final
originId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited