VFSDocumentRequestChangeEvent class

Inheritance

Constructors

VFSDocumentRequestChangeEvent({required String entityId, required EditorAction editorAction, required String originId})
const

Properties

editorAction → EditorAction
final
entityId → String
final
eventId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
originId → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited