WindowPaneCellLayoutChangedEvent class

Indicates that a layout change has occurred and descendants of the cell given by cellId need to be rebuilt. Usually, the new constraints are computed and then a WindowPaneCellRequestReloadEvent is emitted.

Inheritance

Constructors

WindowPaneCellLayoutChangedEvent(String cellId)
const

Properties

cellId String
final
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited