WindowRequestDocumentSetActiveEvent class
- Inheritance
-
- Object
- Event
- WindowEvent
- WindowInstanceEvent
- WindowRequestDocumentSetActiveEvent
Constructors
- WindowRequestDocumentSetActiveEvent({required String documentId, required String? paneId})
-
const
Properties
- documentId → String
-
final
- eventId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- paneId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited