WindowStartupFinishedEvent class

This event is also a bind trigger, which means extensions can give this event's ID as a bind trigger in the AffogatoExtension.bindTriggers property

Inheritance

Constructors

WindowStartupFinishedEvent()
const

Properties

eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited