lsp/lsp_client library

Classes

Command
Represents a command that can be executed in the editor.
CompletionRequestResponse
Diagnostic
Represents a diagnostic, such as a compiler error or warning.
DiagnosticSeverity
The severity of a diagnostic.
Location
Represents a location in a resource, such as a text document.
Position
Represents a Position in a text document (zero-based).
Range
Represents a range in a text document.
ServerResponse
TextDocumentItem
TextEdit
Represents a text edit which describes changes to a text document.
WorkspaceEdit
Represents a workspace edit