Command class

Represents a command that can be executed in the editor.

Constructors

Command({required String title, required String command, List? arguments})
Command.fromJson(Map<String, dynamic> json)
factory

Properties

arguments List?
Arguments that the command handler should be invoked with.
final
command String
The identifier of the actual command handler.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
A human-readable title of the command.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited