Diagnostic class

Represents a diagnostic, such as a compiler error or warning.

Constructors

Diagnostic({required Range range, DiagnosticSeverity? severity, dynamic code, String? message, String? source})
Diagnostic.fromJson(Map<String, dynamic> json)
factory

Properties

code → dynamic
The diagnostic's code, which might appear in the user interface.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
A human-readable string describing the diagnostic.
final
range Range
The range at which the diagnostic applies.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity DiagnosticSeverity?
The diagnostic's severity.
final
source String?
A source code or file if the message comes from an external resource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited