code property
dynamic
code
final
The diagnostic's code, which might appear in the user interface.
Implementation
final dynamic code;
The diagnostic's code, which might appear in the user interface.
final dynamic code;