DiagnosticSeverity class

The severity of a diagnostic.

Constructors

DiagnosticSeverity(int value)
DiagnosticSeverity.fromJson(int json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() int
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

error → const int
hint → const int
information → const int
warning → const int