Location class

Represents a location in a resource, such as a text document.

Constructors

Location({required String uri, required Range range})
Location.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
range Range
The range of the location.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
The URI of the document representing the location.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited