Position class

Represents a Position in a text document (zero-based).

Constructors

Position({required int line, required int character})
Position.fromJson(Map<String, dynamic> json)
factory

Properties

character int
Character offset on a line in a document (zero-based).
final
hashCode int
The hash code for this object.
no setterinherited
line int
Line position in a document (zero-based).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited