Range class

Represents a range in a text document.

Constructors

Range({required Position start, required Position end})
Range.fromJson(Map<String, dynamic> json)
factory

Properties

end Position
The range's end position.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Position
The range's start position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited