TextEdit class

Represents a text edit which describes changes to a text document.

Constructors

TextEdit({required Range range, required String text})
TextEdit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
range Range
The range of the text document to be manipulated. To delete text, the range.start must equal range.end.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The string to be inserted. For delete operations, the string must be empty.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited