WorkspaceEdit class

Represents a workspace edit

Constructors

WorkspaceEdit({Map<String, List<TextEdit>>? changes})
WorkspaceEdit.fromJson(Map<String, dynamic> json)
factory

Properties

changes Map<String, List<TextEdit>>?
Holds changes to existing resources.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited