AffogatoAPI class

An abstraction over the AffogatoEvents class and over commonly-accessed objects such as AffogatoWorkspaceConfigs. Each API in AffogatoAPI has to be instantiated by the user, since each API has its own configurations.

Constructors

AffogatoAPI({required AffogatoExtensionsAPI extensions, required AffogatoWindowAPI window, required AffogatoEditorAPI editor, required AffogatoVFSAPI vfs, required AffogatoWorkspaceAPI workspace})

Properties

editor AffogatoEditorAPI
final
extensions AffogatoExtensionsAPI
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vfs AffogatoVFSAPI
final
window AffogatoWindowAPI
final
workspace AffogatoWorkspaceAPI
final

Methods

deinit() → void
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited