AffogatoDocument class
Stores information about the source, including the path to the file and its contents.
Constructors
- AffogatoDocument({required String docName, required String srcContent, required int maxVersioningLimit, bool readOnly = false})
Properties
- content → String
-
no setter
-
contentVersions
↔ List<
String> -
getter/setter pair
- docName ↔ String
-
getter/setter pair
- extension → String
-
no setter
- hash → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxVersioningLimit → int
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- srcContent ↔ String
-
getter/setter pair
- versionNumber ↔ int
-
getter/setter pair
Methods
-
addVersion(
String content) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override