AffogatoEditorAPI class
- Inheritance
-
- Object
- AffogatoAPIComponent
- AffogatoEditorAPI
Constructors
Properties
- api ↔ AffogatoAPI
-
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceClosedStream
→ Stream<
EditorInstanceClosedEvent> -
final
-
instanceLoadedStream
→ Stream<
EditorInstanceLoadedEvent> -
final
-
instanceRequestReloadStream
→ Stream<
EditorInstanceRequestReloadEvent> -
final
-
instanceRequestToggleSearchOverlay
→ Stream<
EditorInstanceRequestToggleSearchOverlayEvent> -
final
-
keyEventsStream
→ Stream<
EditorKeyEvent> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeInstance(
{required String instanceId}) → void - Visually, this is when the "x" icon of the instance's button on the FileTabBar is pressed
-
init(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestCurrentInstanceToggleSearchOverlay(
) → void - Essentially, this causes the search-and-replace overlay to be toggled.
-
requestInstanceReload(
String instanceId) → void - Calls to this method are extremely expensive since all the state-related data in the AffogatoEditorInstanceState is reloaded
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited