This class is for extensions that override the default behaviour of keys when typing into the editor. It is not to be confused with:
AffogatoKeybindingExtension, which registers keyboard sequences for keyboard shortcuts, triggered when editor text fields are not in focus or when initated with Command/Option keys- AffogatoExtension, the base class from which a standard extension is built. To override default key behaviour, the AffogatoExtension class is insufficient since listening to the AffogatoEvents stream allows only for async processing, rather than the sync processing needed by the dispatcher to determine whether each key should be sent to the TextField or not
The way this class is works is that the base modifier, a new feature in Dart 3.0, prevents the loadExtension method from being overriden. This is useful because the
type of trigger is already known in advance, and can be registered automatically along with some processing
- Inheritance
-
- Object
- AffogatoExtension
- AffogatoEditorKeybindingExtension
- Implementers
Constructors
-
AffogatoEditorKeybindingExtension({required List<
LogicalKeyboardKey> ? keys, required String name, required String displayName, required List<String> bindTriggers})
Properties
-
bindTriggers
→ List<
String> -
finalinherited
- displayName → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
-
keys
→ List<
LogicalKeyboardKey> ? -
final
- name → String
-
finalinherited
- runtime → ExtensionRuntime
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
{required AffogatoAPI api, required EditorKeyEvent editorKeyEvent}) → KeyEventResult -
loadExtension(
AffogatoAPI api) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited