AffogatoExtension class abstract
- Implementers
Constructors
-
AffogatoExtension({required String name, required String displayName, required List<
String> bindTriggers}) -
AffogatoExtension.fromVSCodeManifest(Map<
String, Object?> json)
Properties
-
bindTriggers
→ List<
String> -
final
- displayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
- runtime → ExtensionRuntime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadExtension(
AffogatoAPI api) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited