AffogatoExtensionsEngine class
- Inheritance
-
- Object
- AffogatoAPIComponent
- AffogatoExtensionsEngine
Constructors
- AffogatoExtensionsEngine({required AffogatoWorkspaceConfigs workspaceConfigs})
Properties
- api ↔ AffogatoAPI
-
latefinalinherited
-
editorKeybindingExtensions
→ Map<
LogicalKeyboardKey, AffogatoEditorKeybindingExtension> -
final
-
extensionListeners
→ Map<
String, List< StreamSubscription> > -
final
-
extensions
→ List<
AffogatoExtension> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutsDispatcher ↔ KeyboardShortcutsDispatcher
-
latefinal
- workspaceConfigs → AffogatoWorkspaceConfigs
-
final
Methods
-
addExtension(
AffogatoExtension ext) → void -
deinit(
) → void -
init(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerEditorKeybindingExtension(
AffogatoEditorKeybindingExtension ext) → void -
toString(
) → String -
A string representation of this object.
inherited
-
triggerEditorKeybindings(
EditorKeyEvent event) → KeyEventResult
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
allKeys
→ Iterable<
LogicalKeyboardKey> -
final