AffogatoWindowAPI class
- Inheritance
-
- Object
- AffogatoAPIComponent
- AffogatoWindowAPI
Constructors
- AffogatoWindowAPI({required AffogatoPanesAPI panes})
Properties
- api ↔ AffogatoAPI
-
latefinalinherited
-
closedStream
→ Stream<
WindowClosedEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceDidSetActive
→ Stream<
WindowInstanceDidSetActiveEvent> -
final
-
instanceDidUnsetActive
→ Stream<
WindowInstanceDidUnsetActiveEvent> -
final
-
keyboardEventStream
→ Stream<
WindowKeyboardEvent> -
final
- panes → AffogatoPanesAPI
-
final
-
requestDocumentSetActiveStream
→ Stream<
WindowRequestDocumentSetActiveEvent> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startupFinishedStream
→ Stream<
WindowStartupFinishedEvent> -
final
Methods
-
init(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestDocumentSetActive(
String entityId) → void -
Ensures, by any means, that the entity specified by
entityIdis shown. No checks are performed to verify thatentityIdpoints to a valid entity in the VFS. -
setActiveInstance(
{required String instanceId, required String paneId}) → void -
Called to set the instance given by
instanceIdas the active instance in the pane given bypaneId. -
toString(
) → String -
A string representation of this object.
inherited
-
unsetActiveInstance(
{required String instanceId}) → void -
Called when the instance given by
instanceIdis no longer the active instance.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited