AffogatoWorkspaceAPI class
- Inheritance
-
- Object
- AffogatoAPIComponent
- AffogatoWorkspaceAPI
Constructors
- AffogatoWorkspaceAPI({required AffogatoWorkspaceConfigs workspaceConfigs})
Properties
- api ↔ AffogatoAPI
-
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workspaceConfigs → AffogatoWorkspaceConfigs
-
final
Methods
-
addInstancesToPane(
{required List< String> instanceIds, required String paneId}) → void -
Adds the speicified list of
instanceIdsto the panes data for the pane specified bypaneId. -
createEditorInstancesForEntities(
{required List< AffogatoVFSEntity> entities}) → List<String> -
- Creates AffogatoEditorInstanceData for each file entity in
entities- Adds the instance data to the
workspaceConfigs.instancesData- Returns the ID for each of the created instances
- Creates AffogatoEditorInstanceData for each file entity in
-
init(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setActivePane(
String paneId) → void -
setActivePaneFromInstance(
String instanceId) → String? -
Sets the active pane as the one which contains
instanceId -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited