EditorTheme<C, Y> class
- Implementers
Constructors
- EditorTheme({required Y defaultTextStyle, C? checkboxBorder, C? editorBackground, C? editorForeground, C? editorInactiveSelectionBackgroundAndTerminalInactiveSelectionBackground, C? editorIndentGuideBackground1, C? editorIndentGuideActiveBackground1, C? editorSelectionHighlightBackground, C? listDropBackground, C? activityBarBadgeBackground, C? sideBarTitleForeground, C? inputPlaceholderForeground, C? statusBarItemRemoteForeground, C? statusBarItemRemoteBackground, C? portsIconRunningProcessForeground, C? sideBarSectionHeaderBackground, C? sideBarSectionHeaderBorder, C? tabSelectedBackground, C? tabSelectedForeground, C? tabLastPinnedBorder, C? listActiveSelectionIconForeground, C? widgetBorder, C? actionBarToggledBackground, C? activityBarActiveBorder, C? activityBarBackground, C? activityBarBorder, C? activityBarForeground, C? activityBarInactiveForeground, C? activityBarBadgeForeground, C? badgeBackground, C? badgeForeground, C? buttonBackground, C? buttonBorder, C? buttonForeground, C? buttonHoverBackground, C? buttonSecondaryBackground, C? buttonSecondaryForeground, C? buttonSecondaryHoverBackground, C? chatSlashCommandBackground, C? chatSlashCommandForeground, C? chatEditedFileForeground, C? checkboxBackground, C? debugToolBarBackground, C? descriptionForeground, C? dropdownBackground, C? dropdownBorder, C? dropdownForeground, C? dropdownListBackground, C? editorFindMatchBackground, C? editorGroupBorder, C? editorGroupHeaderTabsBackground, C? editorGroupHeaderTabsBorder, C? editorGutterAddedBackground, C? editorGutterDeletedBackground, C? editorGutterModifiedBackground, C? editorLineNumberActiveForeground, C? editorLineNumberForeground, C? editorOverviewRulerBorder, C? editorWidgetBackground, C? errorForeground, C? focusBorder, C? foreground, C? iconForeground, C? inputBackground, C? inputBorder, C? inputForeground, C? inputOptionActiveBackground, C? inputOptionActiveBorder, C? keybindingLabelForeground, C? notificationCenterHeaderBackground, C? notificationCenterHeaderForeground, C? notificationsBackground, C? notificationsBorder, C? notificationsForeground, C? panelBackground, C? panelBorder, C? panelInputBorder, C? panelTitleActiveBorder, C? panelTitleActiveForeground, C? panelTitleInactiveForeground, C? peekViewEditorBackground, C? peekViewEditorMatchHighlightBackground, C? peekViewResultBackground, C? peekViewResultMatchHighlightBackground, C? pickerGroupBorder, C? progressBarBackground, C? quickInputBackground, C? quickInputForeground, C? settingsDropdownBackground, C? settingsDropdownBorder, C? settingsHeaderForeground, C? settingsModifiedItemIndicator, C? sideBarBackground, C? sideBarBorder, C? sideBarForeground, C? sideBarSectionHeaderForeground, C? statusBarBackground, C? statusBarBorder, C? statusBarDebuggingBackground, C? statusBarDebuggingForeground, C? statusBarFocusBorder, C? statusBarForeground, C? statusBarNoFolderBackground, C? statusBarItemFocusBorder, C? statusBarItemProminentBackground, C? tabActiveBackground, C? tabActiveBorder, C? tabActiveBorderTop, C? tabActiveForeground, C? tabSelectedBorderTop, C? tabBorder, C? tabHoverBackground, C? tabInactiveBackground, C? tabInactiveForeground, C? tabUnfocusedActiveBorder, C? tabUnfocusedActiveBorderTop, C? tabUnfocusedHoverBackground, C? terminalForeground, C? terminalTabActiveBorder, C? textBlockQuoteBackground, C? textBlockQuoteBorder, C? textCodeBlockBackground, C? textLinkActiveForeground, C? textLinkForeground, C? textPreformatForeground, C? textPreformatBackground, C? textSeparatorForeground, C? titleBarActiveBackground, C? titleBarActiveForeground, C? titleBarBorder, C? titleBarInactiveBackground, C? titleBarInactiveForeground, C? welcomePageTileBackground, C? welcomePageProgressForeground})
Properties
- actionBarToggledBackground → C?
-
final
- activityBarActiveBorder → C?
-
final
- activityBarBackground → C?
-
final
- activityBarBadgeBackground → C?
-
final
- activityBarBadgeForeground → C?
-
final
- activityBarBorder → C?
-
final
- activityBarForeground → C?
-
final
- activityBarInactiveForeground → C?
-
final
- badgeBackground → C?
-
final
- badgeForeground → C?
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- chatEditedFileForeground → C?
-
final
- chatSlashCommandBackground → C?
-
final
- chatSlashCommandForeground → C?
-
final
- checkboxBackground → C?
-
final
- checkboxBorder → C?
-
final
- debugToolBarBackground → C?
-
final
- defaultTextStyle → Y
-
final
- descriptionForeground → C?
-
final
- dropdownBackground → C?
-
final
- dropdownBorder → C?
-
final
- dropdownForeground → C?
-
final
- dropdownListBackground → C?
-
final
- editorBackground → C?
-
final
- editorFindMatchBackground → C?
-
final
- editorForeground → C?
-
final
- editorGroupBorder → C?
-
final
- editorGroupHeaderTabsBackground → C?
-
final
- editorGroupHeaderTabsBorder → C?
-
final
- editorGutterAddedBackground → C?
-
final
- editorGutterDeletedBackground → C?
-
final
- editorGutterModifiedBackground → C?
-
final
- editorInactiveSelectionBackgroundAndTerminalInactiveSelectionBackground → C?
-
final
- editorIndentGuideActiveBackground1 → C?
-
final
- editorIndentGuideBackground1 → C?
-
final
- editorLineNumberActiveForeground → C?
-
final
- editorLineNumberForeground → C?
-
final
- editorOverviewRulerBorder → C?
-
final
- editorSelectionHighlightBackground → C?
-
final
- editorWidgetBackground → C?
-
final
- errorForeground → C?
-
final
- focusBorder → C?
-
final
- foreground → C?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconForeground → C?
-
final
- inputBackground → C?
-
final
- inputBorder → C?
-
final
- inputForeground → C?
-
final
- inputOptionActiveBackground → C?
-
final
- inputOptionActiveBorder → C?
-
final
- inputPlaceholderForeground → C?
-
final
- keybindingLabelForeground → C?
-
final
- listActiveSelectionIconForeground → C?
-
final
- listDropBackground → C?
-
final
-
final
-
final
-
final
-
final
- notificationCenterHeaderBackground → C?
-
final
- notificationCenterHeaderForeground → C?
-
final
- notificationsBackground → C?
-
final
- notificationsBorder → C?
-
final
- notificationsForeground → C?
-
final
- panelBackground → C?
-
final
- panelBorder → C?
-
final
- panelInputBorder → C?
-
final
- panelTitleActiveBorder → C?
-
final
- panelTitleActiveForeground → C?
-
final
- panelTitleInactiveForeground → C?
-
final
- peekViewEditorBackground → C?
-
final
- peekViewEditorMatchHighlightBackground → C?
-
final
- peekViewResultBackground → C?
-
final
- peekViewResultMatchHighlightBackground → C?
-
final
- pickerGroupBorder → C?
-
final
- portsIconRunningProcessForeground → C?
-
final
- progressBarBackground → C?
-
final
- quickInputBackground → C?
-
final
- quickInputForeground → C?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingsDropdownBackground → C?
-
final
- settingsDropdownBorder → C?
-
final
- settingsHeaderForeground → C?
-
final
- settingsModifiedItemIndicator → C?
-
final
- sideBarBackground → C?
-
final
- sideBarBorder → C?
-
final
- sideBarForeground → C?
-
final
- sideBarSectionHeaderBackground → C?
-
final
- sideBarSectionHeaderBorder → C?
-
final
- sideBarSectionHeaderForeground → C?
-
final
- sideBarTitleForeground → C?
-
final
- statusBarBackground → C?
-
final
- statusBarBorder → C?
-
final
- statusBarDebuggingBackground → C?
-
final
- statusBarDebuggingForeground → C?
-
final
- statusBarFocusBorder → C?
-
final
- statusBarForeground → C?
-
final
- statusBarItemFocusBorder → C?
-
final
- statusBarItemProminentBackground → C?
-
final
- statusBarItemRemoteBackground → C?
-
final
- statusBarItemRemoteForeground → C?
-
final
- statusBarNoFolderBackground → C?
-
final
- tabActiveBackground → C?
-
final
- tabActiveBorder → C?
-
final
- tabActiveBorderTop → C?
-
final
- tabActiveForeground → C?
-
final
- tabBorder → C?
-
final
- tabHoverBackground → C?
-
final
- tabInactiveBackground → C?
-
final
- tabInactiveForeground → C?
-
final
- tabLastPinnedBorder → C?
-
final
- tabSelectedBackground → C?
-
final
- tabSelectedBorderTop → C?
-
final
- tabSelectedForeground → C?
-
final
- tabUnfocusedActiveBorder → C?
-
final
- tabUnfocusedActiveBorderTop → C?
-
final
- tabUnfocusedHoverBackground → C?
-
final
- terminalForeground → C?
-
final
- terminalTabActiveBorder → C?
-
final
- textBlockQuoteBackground → C?
-
final
- textBlockQuoteBorder → C?
-
final
- textCodeBlockBackground → C?
-
final
- textLinkActiveForeground → C?
-
final
- textLinkForeground → C?
-
final
- textPreformatBackground → C?
-
final
- textPreformatForeground → C?
-
final
- textSeparatorForeground → C?
-
final
- titleBarActiveBackground → C?
-
final
- titleBarActiveForeground → C?
-
final
- titleBarBorder → C?
-
final
- titleBarInactiveBackground → C?
-
final
- titleBarInactiveForeground → C?
-
final
- welcomePageProgressForeground → C?
-
final
- welcomePageTileBackground → C?
-
final
- widgetBorder → C?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited