ParseException class
Constructors
- ParseException({required ExceptionType exceptionType, required Token token, required String message, String? description, StackTrace? stackTrace})
Properties
- description → String?
-
final
- exceptionType → ExceptionType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
- token → Token
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
presentExceptionLong(
) → String -
presentExceptionShort(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited