TokenMapping<K, V> class
abstract
Generates a Map whose keys are of type K and values type V.
This provides a better way to natively define token mappings, by allowing
token scopes to be grouped, named, and for text styles to be overriden.
Constructors
- TokenMapping({required V defaultStyle})
Properties
- defaultStyle → V
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mapping
→ Map<
K, V> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scope(
List< K> names, {required V settings}) → void - Adds a new scope setting
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited