windowRequestDocumentSetActiveEventsController property
StreamController<WindowRequestDocumentSetActiveEvent>
windowRequestDocumentSetActiveEventsController
final
Emitted to request for a document to be set as the active instance, regardless of whether there is an instance associated with it or whether the instance is currently in any of the panes.
Implementation
static final StreamController<WindowRequestDocumentSetActiveEvent>
windowRequestDocumentSetActiveEventsController =
StreamController.broadcast();