AffogatoWorkspaceConfigs class

Constructors

AffogatoWorkspaceConfigs({Map<String, PaneData>? defaultPanesData, String? activePane, PaneList? panesLayout, required String projectName, required Map<String, PaneInstanceData> instancesData, required ThemeBundle<dynamic, Color, TextStyle, TextSpan> themeBundle, required Map<LanguageBundle, List<String>> languageBundles, required AffogatoStylingConfigs stylingConfigs, required List<AffogatoExtension> extensions})

Properties

activeInstance String?
getter/setter pair
activePane String?
getter/setter pair
entitiesLocation Map<String, (String, String)>
A mapping of entity IDs to (instanceId, paneId) that contains the entity.
final
extensions List<AffogatoExtension>
final
hashCode int
The hash code for this object.
no setteroverride
instancesData Map<String, PaneInstanceData>
Stores the instance states for opened instances in the various panes, each one associated with its corresponding PaneInstanceData object
final
isPrimaryBarExpanded bool
getter/setter pair
languageBundles Map<LanguageBundle, List<String>>
A mapping of LanguageBundles to possible file extensions for each language Each entry will be checked first to find a suitable user-defined LanguageBundle for a given file extension, before the LanguageBundle.fileAssociationContributions that is provided by the creator of the language bundle is traversed.
final
panesData Map<String, PaneData>
A mapping of pane IDs to the IDs of the PaneInstances contained by that pane
final
panesLayout PaneList
getter/setter pair
projectName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stylingConfigs AffogatoStylingConfigs
final
themeBundle ThemeBundle<dynamic, Color, TextStyle, TextSpan>
final
vfs AffogatoVFS
final

Methods

detectLanguage(String extension) LanguageBundle?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePane(String paneId) → void
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited