AutoIndenterExtension class final
- Inheritance
-
- Object
- AffogatoExtension
- AffogatoEditorKeybindingExtension
- AutoIndenterExtension
Constructors
Properties
- api ↔ AffogatoAPI
-
getter/setter pair
-
bindTriggers
→ List<
String> -
finalinherited
- displayName → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
-
keys
→ List<
LogicalKeyboardKey> ? -
finalinherited
- name → String
-
finalinherited
- runtime → ExtensionRuntime
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
{required AffogatoAPI api, required EditorKeyEvent editorKeyEvent}) → KeyEventResult -
override
-
loadExtension(
AffogatoAPI api) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
numSpacesBeforeFirstChar(
String line) → int -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
triggerChars
→ const Map<
String, String>