CompletionsController class
Constructors
-
CompletionsController({required List<
String> dictionary, required void refresh(VoidCallback ), required void onAcceptAndDismiss(String)})
Properties
- completionItem ↔ int
-
getter/setter pair
-
currentCompletions
↔ List<
String> ? -
getter/setter pair
- currentWord ↔ String
-
getter/setter pair
-
dictionary
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAcceptAndDismiss → void Function(String)
-
final
- refresh → void Function(VoidCallback )
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showingCompletions ↔ bool
-
getter/setter pair
Methods
-
handleKeyEvent(
KeyEvent key) → KeyEventResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseAllWordsInDocument(
{required String content}) → List< String> -
registerTextChanged(
{required String content, required TextSelection selection, required KeyEvent keyEvent}) → List< String> ? - If a valid word (present in the dictionary) is being typed, a List<String> with the valid completions is returned, and null otherwise. This method should only be called if a LSPClient is not in use.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCompletionIndex(
int newIndex) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited