EditorInstanceLoadedEvent class
The instanceId gives the ID of the instance that was loaded, the paneId containing that instance, as well as the documentId being handled by the instance.
- Inheritance
-
- Object
- Event
- EditorEvent
- EditorInstanceEvent
- EditorInstanceLoadedEvent
Constructors
- EditorInstanceLoadedEvent({required String instanceId, required String paneId, required String documentId})
-
const
Properties
- documentId → String
-
final
- eventId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceId → String
-
final
- paneId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited