MultiplePaneList class sealed
- Inheritance
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double
-
getter/setter pairinherited
- id → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ List<
PaneList> -
getter/setter pair
- width ↔ double
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pathToPane(
String paneId, {bool removeGivenPane = false}) → List< MultiplePaneList> ? -
Uses DFS to search for the ancestor tree of a given pane ID. Set
removeGivenPaneif the SinglePaneList containing thepaneIdshould be deleted. This is used by theremovePaneByIdmethod. -
toString(
) → String -
A string representation of this object.
inherited
-
toTree(
int indent) → String -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited