VFSDocumentEvent class abstract
originId can be any identifier to distinguish between different sources of a VFSDocumentEvent. Since some components read and write to the same stream, checking against the originId helps prevent infinite loops of responding to their own events.
- Inheritance
- Implementers
Constructors
- VFSDocumentEvent(String id, {required String originId})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited