WindowPaneCellRequestReloadEvent class
Requests the PaneLayoutCellWidget given by cellId to reload itself and its
descendants. Each pane cell listens to events from this stream that have
their cellId. Once such an event is received, setState is called and that widget will then
emit more such WindowPaneCellRequestReloadEvents, one for each cellId in its immediate children.
- Inheritance
-
- Object
- Event
- WindowEvent
- WindowPaneEvent
- WindowPaneCellRequestReloadEvent
Constructors
- WindowPaneCellRequestReloadEvent(String cellId)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited